@@ -43,7 +43,7 @@ class Advertisement(dbus.service.Object):
         self.solicit_uuids = None
         self.manufacturer_data = None
         self.service_data = None
-        self.discoverable = True
+        self.discoverable = None
         self.include_tx_power = None
         dbus.service.Object.__init__(self, self.bus, self.path)
 
